Module earthgravity

Module earthgravity 

Zonal gravity model for Earth gravity

Structs

Gravity

Enums

Error
Errors produced by the earthgravity module.
GravityModel
Gravity model enumeration

Functions

accel
Return acceleration due to Earth gravity at the input position. The acceleration does not include the centrifugal force, and is output in m/s^2 in the International Terrestrial Reference Frame (ITRF)
accel_and_partials
Return acceleration due to Earth gravity at the input position, as well as acceleration partials with respect to ITRF position, i.e. d a / dr
accel_jgm3
egm96
Singleton for EGM96 gravity model
gravhash
Gravity model hash
init_from_bytes
Initialize the gravity-model singleton for model from an in-memory byte buffer.
init_from_path
Initialize the gravity-model singleton for model from a file at path.
itu_grace16
Singleton for ITU GRACE16 gravity model
jgm2
Singleton for JGM2 gravity model
jgm3
Singleton for JGM3 gravity model

Type Aliases

Result
Convenient type alias used throughout the earthgravity module.