pub enum SolarSystem {
Mercury = 0,
Venus = 1,
EMB = 2,
Mars = 3,
Jupiter = 4,
Saturn = 5,
Uranus = 6,
Neptune = 7,
Pluto = 8,
Moon = 9,
Sun = 10,
}Expand description
Solar system bodies
Coordinate origin is the solar system barycenter
Notes:
- For native JPL Ephemerides function calls: positions for all bodies are natively relative to solar system barycenter, with exception of moon, which is computed in Geocentric system
- EMB (2) is the Earth-Moon barycenter
- The sun position is relative to the solar system barycenter (it will be close to origin)
Variants
Mercury = 0
Mercury
Venus = 1
Venus
EMB = 2
Earth-Moon Barycenter
Mars = 3
Mars
Jupiter = 4
Jupiter
Saturn = 5
Saturn
Uranus = 6
Uranus
Neptune = 7
Neptune
Pluto = 8
Pluto
Moon = 9
Moon (Geocentric)
Sun = 10
Sun