Module mathtypes

Module mathtypes 

Mathematical types used throughout the library

This module defines commonly used mathematical types such as vectors, matrices, and quaternions using the numeris crate. These types are used for representing positions, velocities, orientations, and other mathematical constructs in the library.

Type Aliases

DMatrix
Matrix
Matrix3
Matrix6
Matrix67
Quaternion
Vector
Vector2
Vector3
Vector6