Module spaceweather

Module spaceweather 

Space Weather

Structs

SpaceWeatherRecord

Enums

Error
Errors produced by the spaceweather module.

Functions

get
Return full Space Weather record from Space Weather file, as a function of requested instant in time.
init_from_bytes
Initialize the space-weather singleton from an in-memory byte buffer.
init_from_path
Initialize the space-weather singleton from a file at path.
update
Download new Space Weather file, and load it.

Type Aliases

Result
Convenient type alias used throughout the spaceweather module.