Utility functions
Structs
Functions
- Return libary compile date
- Return true if data files exist in data directory
- Get directory where astronomy data is stored
- Return git hash of compiled library
- Return git tag of compiled library
- Explicitly set data directory where data files will be stored Generally this should not be needed