Module datadir

Module datadir 

Enums

Error
Errors that can occur while resolving or setting the satkit data directory.

Functions

data_found
Return true if data files exist in data directory
datadir
Get directory where astronomy data is stored
set_datadir
Explicitly set data directory where data files will be stored Generally this should not be needed
testdirs

Type Aliases

Result
Convenient type alias used throughout the datadir module.