Conversion between coordinate frames
Functions
- earth_
rotation_ angle - Earth Rotation Angle
- eqeq
- Equation of Equinoxes Equation of the equinoxes
- gast
- Greenwich Apparent Sidereal Time
- gmst
- Greenwich Mean Sidereal Time
- qcirs2gcrs
- Return quatnerion represention rotation from the CIRS (Celestial Intermediate Reference System) to the GCRS (Geocentric Celestial Reference Frame) at given instant
- qcirs2gcrs_
dxdy - qgcrf2itrf
- Quaternion representing rotation from the Geocentric Celestial Reference Frame (GCRF) to the International Terrestrial Reference Frame (ITRF)
- qgcrf2itrf_
approx - Approximate rotation from Geocentric Celestrial Reference Frame to International Terrestrial Reference Frame
- qitrf2gcrf
- Quaternion representing rotation from the International Terrestrial Reference Frame (ITRF) to the Geocentric Celestial Reference Frame (GCRF)
- qitrf2gcrf_
approx - Approximate rotation from International Terrestrial Reference Frame to Geocentric Celestrial Reference Frame
- qitrf2tirs
- Rotation from International Terrestrial Reference Frame (ITRF) to the Terrestrial Intermediate Reference System (TIRS)
- qmod2gcrf
- Rotate from Mean Equinix of Date (MOD) coordinate frame to Geocentric Celestrial Reference Frame
- qteme2gcrf
- Rotation from True Equator Mean Equinox (TEME) frame to Geocentric Celestial Reference Frame (GCRF)
- qteme2itrf
- Rotation from True Equator Mean Equinox (TEME) frame to International Terrestrial Reference Frame (ITRF)
- qtirs2cirs
- Quaternion representing rotation from the Terrestrial Intermediate Reference System to the Celestial Intermediate Reference System
- qtod2mod_
approx - Approximate rotation from True of Date to Mean of Date coordinate frame