pub struct PropSettings {
pub gravity_degree: u16,
pub gravity_order: u16,
pub abs_error: f64,
pub rel_error: f64,
pub use_spaceweather: bool,
pub use_sun_gravity: bool,
pub use_moon_gravity: bool,
pub enable_interp: bool,
pub precomputed: Option<Precomputed>,
}Expand description
Propagation settings
These include
gravity_degree- maximum degree of spherical harmonic gravity model. Default is 4gravity_order- maximum order of spherical harmonic gravity model. Default is same asgravity_degree. Must be ≤gravity_degree.abs_error- the maximum absolute error for the infinity norm of the state in Runge-Kutta integrator. Default is 1e-8rel_error- the maximum relative error for the infinity norm of the state in Runge-Kutta integrator. Default is 1e-8use_spaceweather- Do we use space weather when computing the atmospheric density. Default is trueuse_sun_gravity- Do we include sun third-body gravitational perturbation. Default is trueuse_moon_gravity- Do we include moon third-body gravitational perturbation. Default is trueenable_interp- Do we enable interpolation of the state between begin and end times. Default is true slight computation savings if set to false
Fields
gravity_degree: u16gravity_order: u16abs_error: f64rel_error: f64use_spaceweather: booluse_sun_gravity: booluse_moon_gravity: boolenable_interp: boolprecomputed: Option<Precomputed>Implementations
Sourceimpl PropSettings
impl PropSettings
Sourcepub fn precompute_terms<T: TimeLike>(
&mut self,
begin: &T,
end: &T,
) -> Result<()>
pub fn precompute_terms<T: TimeLike>( &mut self, begin: &T, end: &T, ) -> Result<()>
Precompute terms between begin and end instants
Arguments
begin- Begin instantend- End instant
Pre-computes inertial to earth-fixed rotation vector (used for Earth gravity calculation), sun, and moon positions between the begin and end instants. These are used in the force model when propagating orbits
Pre-computing these terms means the settings can be used for multiple propagations between the same begin and end instants without needing to recompute these terms each time. (significant speedup when propagating many orbits over the same time span)
Errors
Returns error if precomputation fails
Example
use satkit::orbitprop::PropSettings;
use satkit::Instant;
let begin = Instant::now();
let end = begin + satkit::Duration::from_hours(1.0);
let mut props = PropSettings::default();
props.precompute_terms(&begin, &end).unwrap();
pub fn precompute_terms_with_step<T: TimeLike>( &mut self, begin: &T, end: &T, step_secs: f64, ) -> Result<()>