Skip to main content Module prelude Copy item path Source pub use crate::consts ::*;pub use crate::earthgravity ::*;pub use crate::frametransform ::*;pub use crate::itrfcoord ::*;pub use crate::jplephem ::*;pub use crate::kepler ::*;pub use crate::lpephem ::*;pub use crate::nrlmsise ::*;pub use crate::omm ::*;pub use crate::orbitprop ::*;pub use crate::sgp4 ::*;pub use crate::spaceweather ::*;pub use crate::tle ::*;pub use crate::utils ::*;Duration Structure representing a duration in time
This can be used to add or subtract times from
an Instant object. Instant A module for handling time and date conversions. Time is stored natively as
the number of microseconds since the Unix epoch (1970-01-01 00:00:00 UTC)
with leap seconds accounted for. SolarSystem Solar system bodies TimeScale Time Scales Weekday Day of week TimeLike Trait for time-like types usable by satkit APIs that require time scale conversions.