Space Weather
Structs
Enums
- Error
- Errors produced by the
spaceweathermodule.
Functions
- get
- Return full Space Weather record from Space Weather file, as a function of requested instant in time.
- init_
from_ bytes - Initialize the space-weather singleton from an in-memory byte buffer.
- init_
from_ path - Initialize the space-weather singleton from a file at
path. - update
- Download new Space Weather file, and load it.
Type Aliases
- Result
- Convenient type alias used throughout the
spaceweathermodule.