Module spaceweather

Module spaceweather 

Space Weather

Structs

SpaceWeatherRecord

Functions

get
Return full Space Weather record from Space Weather file, as a function of requested instant in time, linearly interpolated between time records in the file
update
Download new Space Weather file, and load it.