Module spaceweather
satkit
0.11.0
Module spaceweather
Module Items
Structs
Functions
In crate satkit
satkit
Module
spaceweather
Space Weather
Structs

Space
Weather
Record
Functions

get
Return full Space Weather record from Space Weather file, as a function of requested instant in time, linearly interpolated between time records in the file
update
Download new Space Weather file, and load it.